###########################################################################
library(foreign)
clothing = read.dta("clothing.dta" );
attach(clothing); 
  
N = nrow(clothing)
attach(clothing);

windows()
hist(tsales, 30, col = "blue")      # Histogram
#-------------------------------------------------------------------------------
# simple (univariate) regression of log tsales on log hoursw
y = log(tsales)
windows()
hist(y, 30,col="blue")  
x1 = log(hoursw)
windows()
plot(x1, y) 
N = length(y)
# Estimation of the regression coefficients
beta1.hat = cov(x1,y)/var(x1)
beta0.hat = mean(y)-beta1.hat*mean(x1)   # intercept
y.hat = beta0.hat+beta1.hat*x1           # Fitted values
windows()
plot(x1, y)
abline( beta0.hat,beta1.hat, col="red")
e.y = y - y.hat      # OLS residuals
s2.hat = sum(e.y^2)/(N-2)  # Estimate of \sigma^2
sqrt(s2.hat)               # residual standard error 
# alternatively this is obtained as 
regr1 = lm( y ~ x1);
summary(regr1)
e.y = residuals(regr1)
#------------------------------------------------------------------------------
# Bivariate regression: Illustration of Frisch-Waugh-Lovell Theorem 
# https://en.wikipedia.org/wiki/Frisch%E2%80%93Waugh%E2%80%93Lovell_theorem

x2 = log(ssize)  # log of store size
## multiple regression model
regr = lm( y ~  x1+x2) 
summary(regr)   
gamma.hat = coefficients(regr)[3]  # OLS estimate
CovBeta = vcov(regr) # covariance matrix for model parameters  
CovBeta[3,3] # variance of gamma_hat
sqrt(CovBeta[3,3]) # std err of gamma_hat (compare with table)
#-------------------------------------------------------------------------------
# regress x2 on x1 and get the residuals 
b21.hat  = cov(x1,x2)/var(x1)
b20.hat  = mean(x2)-b21.hat*mean(x1)
x2.hat = b20.hat+b21.hat*x1 # fitted values
e.x2 = x2- x2.hat           # residuals
# or more simply
regr2 = lm( x2 ~ x1);
e.x2 = residuals(regr2)
# regress residuals    
summary(lm(e.y~e.x2))      # OLS regression with intercept
gamma.hat = cov(e.x2,e.y)/var(e.x2)
windows()
plot(e.x2,e.y)
 